@@ -2,7 +2,9 @@ import aiohttp
 import asyncio
 import json
 import logging
+
 from typing import List
+from .currency import CEROS
 from .queries import get_cancel_order_query, get_open_orders_query, get_new_position_query, get_cancel_multiple_orders_query
 
 
@@ -11,7 +13,7 @@ async def close_order_by_id(self, order_id: str, session: aiohttp.ClientSession)
         logging.info(f"Closing Order {order_id}")
         query_str = get_cancel_order_query(order_id=order_id)
         payload = {"query": query_str, "variables": {}}
-        response = await self.client.request("POST", "graphql", session, payload)
+        response = await self.request("POST", "graphql", session, payload)
         logging.info(response)
 
         if response["data"].get("cancelOrder", None) == None:
@@ -44,7 +46,7 @@ async def get_open_orders(self, session: aiohttp.ClientSession):
     try:
         query_str = get_open_orders_query()
         payload = {"query": query_str, "variables": {}}
-        response = await self.client.request("POST", "graphql", session, payload)
+        response = await self.request("POST", "graphql", session, payload)
         logging.info(response)
 
         if "data" in response:
@@ -60,6 +62,30 @@ async def get_open_orders(self, session: aiohttp.ClientSession):
         raise Exception("Could not get open ids")
 
 
+async def get_open_orders_by_market(
+    self, market: str, session: aiohttp.ClientSession
+):
+    try:
+        query_str = get_open_orders_query()
+        payload = {"query": query_str, "variables": {}}
+        response = await self.client.request("POST", "graphql", session, payload)
+        logging.info(response)
+
+        if "data" in response:
+            ids = {
+                order["_id"]: order["market"]["code"]
+                for order in response["data"]["orders"]["items"]
+                if order["market"]["code"] == market.replace("/", "")
+                and order["sell"] == True
+            }
+            logging.info(f"OPEN ORDERS in {market}: {ids}")
+            return ids
+        return []
+    except Exception as err:
+        logging.debug(err)
+        raise Exception(f"Could not get open ids for market {market}")
+
+
 async def close_orders_by_market(self, market: str, session: aiohttp.ClientSession):
     try:
         logging.info(f"CLOSING ORDERS BY {market}")
@@ -76,7 +102,7 @@ async def get_order_status(self, order_id: str, session: aiohttp.ClientSession):
     try:
         query_str = get_order_status(order_id=order_id)
         payload = {"query": query_str, "variables": {}}
-        response = await self.client.request("POST", "graphql", session, payload)
+        response = await self.request("POST", "graphql", session, payload)
         logging.debug(response)
 
         if "data" in response:
@@ -94,7 +120,7 @@ async def close_orders(self, order_ids: List[str], session: aiohttp.ClientSessio
         str_ids = json.dumps(order_ids)
         query_str = get_cancel_multiple_orders_query(str_ids=str_ids)
         payload = {"query": query_str, "variables": {}}
-        response = await self.client.request("POST", "graphql", session, payload)
+        response = await self.request("POST", "graphql", session, payload)
 
         for order in order_ids:
             status = await self.get_order_status(order_id=order, session=session)
@@ -134,7 +160,7 @@ async def new_position(
         )
 
         payload = {"query": query_place_order, "variables": {}}
-        response = await self.client.request("POST", "graphql", session, payload)
+        response = await self.request("POST", "graphql", session, payload)
         logging.info(response)
 
         if response["data"].get("errors", None) != None:
